==> dataone.libclient-3.4.0-py3-none-any.whl: d1_client/util.py <==
# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2019 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import re


def normalize_request_response_dump(dump_str):
    dump_list = dump_str.splitlines()
    request_list = []
    response_list = []
    body_list = []

    for i, s in enumerate(dump_list):
        m = re.match(br'< (.*)', s)
        if m:
            if m.group(1):
                request_list.append(s)
            continue
        m = re.match(br'> (.*)', s)
        if m:
            if m.group(1):
                response_list.append(s)
            continue
        if not s:
            continue
        body_list = dump_list[i:]
        break

    return '\n\n'.join(
        [
            '\n'.join([s.decode('utf-8', 'ignore') for s in sorted(request_list)]),
            '\n'.join([s.decode('utf-8', 'ignore') for s in sorted(response_list)]),
            '\n'.join([s.decode('utf-8', 'ignore') for s in body_list]),
        ]
    )

==> dataone.libclient-3.4.7-py3-none-any.whl: d1_client/util.py <==
# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2019 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import re


def normalize_request_response_dump(dump_str):
    dump_list = dump_str.splitlines()
    request_list = []
    response_list = []
    body_list = []

    for i, s in enumerate(dump_list):
        m = re.match(br"< (.*)", s)
        if m:
            if m.group(1):
                request_list.append(s)
            continue
        m = re.match(br"> (.*)", s)
        if m:
            if m.group(1):
                response_list.append(s)
            continue
        if not s:
            continue
        body_list = dump_list[i:]
        break

    return "\n\n".join(
        [
            "\n".join([s.decode("utf-8", "ignore") for s in sorted(request_list)]),
            "\n".join([s.decode("utf-8", "ignore") for s in sorted(response_list)]),
            "\n".join([s.decode("utf-8", "ignore") for s in body_list]),
        ]
    )
